@@ -1,5 +1,7 @@
 from django.apps import AppConfig
 from django.db import models
+from django.forms.fields import CharField
+from django.utils.translation import ugettext_lazy as _
 
 from drf_yasg import openapi
 from drf_yasg.inspectors.field import (
@@ -32,6 +34,7 @@ class ZDSSchemaConfig(AppConfig):
         patch_duration_type()
         register_serializer_field()
         set_custom_hyperlinkedmodelserializer_field()
+        set_charfield_error_messages()
 
 
 def patch_duration_type():
@@ -69,3 +72,17 @@ def set_custom_hyperlinkedmodelserializer_field():
     serializers.HyperlinkedModelSerializer.serializer_related_field = (
         LengthHyperlinkedRelatedField
     )
+
+
+def set_charfield_error_messages():
+    """
+    Monkey-patches Django forms CharField to supply error messages for min and
+    max_length. If these are not specified, the serialized validation errors
+    would be empty
+    """
+    CharField.default_error_messages.update(
+        {
+            "max_length": _("The value has too many characters"),
+            "min_length": _("The value has too few characters"),
+        }
+    )
